@@ -42,6 +42,7 @@ sub init_human_text{
 	['apache2',_('New generation Web Server'),'apache2'],
 	['apmd',_('Monitors battery status for some older laptops'),'apmd'],
 	['atd',_('Enables scheduling of jobs'),'atd'],
+	['autofs',_('Automounter for Linux'),'autofs'],
 	['binfmt-support',_('Support for extra formats to run programs'),0],
 	['bind9', _('Service to get internet domain names'),'named'],
 	['bootlogd',_('Saves messages at boot to a log file'),'bootlogd'],
@@ -53,6 +54,7 @@ sub init_human_text{
 	['dbus',_('Delivers messages between applications'),'dbus-daemon'],
 	['ddclient',_('Updates your details on DNS hosting providers'),'ddclient'],
 	['dns-clean',_('Configures your system for internet access via a modem'),0], 
+	['dhcp3-server',_('Provides IP addresses to clients via DHCP'),'dhcpd3'],
 	['dictd',_('Dictionary Server'),'dictd'],
 	['evms',_('Hard Disk Volume Management'),0],
 	['fam',_('Detects changes in files/directories'),'famd'],
@@ -79,6 +81,7 @@ sub init_human_text{
 	['networking',_('Manages your Internet connection'),0],
 	['ntpdate',_('Update the system time using the Internet'),0],
 	['nvidia-glx',_('NVIDIA video card management'),0],
+	['nvidia-kernel',_('Common files for NVIDIA video cards'),0],
 	['pcmcia',_('Manages the insertion/removal of Laptop cards'),'cardmgr'], 
 	['postfix',_('High performance Mail Server'),'master'],
 	['powernowd',_('Controls CPU speed and voltage to save power'),'powernowd'],
@@ -88,7 +91,9 @@ sub init_human_text{
 	['samba',_('Share files among computers on a LAN'),'smbd'],
 	['sl-modem-daemon',_('SmartLink modem management'),'slmodemd'],
 	['squid',_('Internet WWW proxy server'),'squid'],
+	['spamassassin',_('Mail spam filter'),'spamd'],
 	['ssh',_('Allows users securely to log into the machine remotely'),'sshd'],
+	['stop-bootlogd',_('Stops saving boot messages to a log file'),0],
 	['sudo',_('Allows specific users to gain superuser status'),0],
 	['sysklogd',_('System Logging Service'),'syslogd'],
 	['tpb',_('Program to use the IBM ThinkPad(tm) special keys'),'tpb'],
@@ -99,7 +104,8 @@ sub init_human_text{
 	['vsftpd',_('The Very Secure FTP daemon'),'vsftpd'],
 	['webmin',_('Web-based remote administration for this computer'),'miniserv.pl'],
 	['wifi-radar',_('Graphical utility for managing wi-fi connections'),'wifi-radar'],
-	['xorg-common',_('Main Graphical Interface'),'Xorg']
+	['xorg-common',_('Main Graphical Interface'),'Xorg'],
+	['zope',_('Open Source Web Application Server'),'zope']
 	){
 	    my($name,$description,$daemon)=@$_;
 	    $hdata->{$name}->{description} = $description;
